# Scripts usage example

In this directory you will find some examples of LukProt BLAST server usage and script usage. Human huntingtin was chosen as as example protein.

It is assumed that the software is installed and the environment variables are exported. Refer to the main database README file.

First, go to https://lukprot.hirszfeld.pl/ and use `HTT-query.fa` as the input. The BLAST parameters are:

- the whole LukProt database selected (either a tick next to LukProt_v1.5.1, or next to LukProt_v1.5.1_alphabetical. Two ticks will just double the search time and the number of results)
- search parameters: `-evalue 1e-5 -max_target_seqs 999999`

Wait a few minutes for the search to complete. There will be 1145 results. They can be found in the file `HTT-result.fa`. Here is a link to an archived version of the results: https://share.sequenceserver.com/shares/c4fdd98c7371e1b9c235f7e4494450f1c8c3b1647e6d5008e0cb8498c1be0751-d37bab16-5329-4e0e-916a-0350bb035291

The number of sequences is quite high. This commands can be run to filter out all sequences from non-Metazoan datasets:

~~~
seqkit_extract_LP_seqs_using_lpidlist.sh 31 $LPMETADATA/examples/huntingtin_example/HTT-result.fa
~~~

Output file: `LPMETADATA/examples/huntingtin_example/HTT-result.fa.31_Metazoa.fa`

And this if one only wants to look at sequences from the LCS:

~~~
seqkit_extract_LP_seqs_using_lpidlist.sh LCS $LPMETADATA/examples/huntingtin_example/HTT-result.fa
~~~

Output file: `LPMETADATA/examples/huntingtin_example/HTT-result.fa.LCS.fa`

The script above will also print out the stats of the FASTA files that have similar names.

A step one might take next is to align the sequences. This can be done, for example, using FAMSA:

~~~
famsa -refine_mode on $LPMETADATA/examples/huntingtin_example/HTT-result.fa.LCS.fa LPMETADATA/examples/huntingtin_example/HTT-result.fa.LCS.famsa
~~~

This should not take long. There are multiple ways to proceed now. It could be useful to trim the alignment using some predefined criteria. The script `multi-trimal.sh` provides an array of trimmed alignments and prints their stats. For example, running this command:

~~~
cd $LPMETADATA/examples/huntingtin_example && multi-trimal.sh HTT-result.fa.LCS.famsa`
~~~

will result in this output:

~~~
Processing gap threshold 0.01
Processing gap threshold 0.05
Processing gap threshold 0.1
Processing gap threshold 0.2
Processing gap threshold 0.3
Processing gap threshold 0.4
Processing gap threshold 0.5
Processing gap threshold 0.6
[ERRO] fastx: invalid FASTA/Q format
Processing gap threshold 0.7
[ERRO] fastx: invalid FASTA/Q format
Processing gap threshold 0.8
[ERRO] fastx: invalid FASTA/Q format
Processing gap threshold 0.9
[ERRO] fastx: invalid FASTA/Q format
Removing empty sequences
processed files:  8 / 8 [======================================] ETA: 0s. done
file                                               format  type     num_seqs    sum_len  min_len  avg_len  max_len
HTT-result.fa.LCS.famsa                            FASTA   Protein       162  1,310,742    8,091    8,091    8,091
multi-trimal-out/HTT-result.fa.LCS.famsa.gt001.fa  FASTA   Protein       162    948,996    5,858    5,858    5,858
multi-trimal-out/HTT-result.fa.LCS.famsa.gt005.fa  FASTA   Protein       162    572,994    3,537    3,537    3,537
multi-trimal-out/HTT-result.fa.LCS.famsa.gt010.fa  FASTA   Protein       162    521,316    3,218    3,218    3,218
multi-trimal-out/HTT-result.fa.LCS.famsa.gt020.fa  FASTA   Protein       162    498,474    3,077    3,077    3,077
multi-trimal-out/HTT-result.fa.LCS.famsa.gt030.fa  FASTA   Protein       162    474,498    2,929    2,929    2,929
multi-trimal-out/HTT-result.fa.LCS.famsa.gt040.fa  FASTA   Protein       162    443,232    2,736    2,736    2,736
multi-trimal-out/HTT-result.fa.LCS.famsa.gt050.fa  FASTA   Protein       162    367,416    2,268    2,268    2,268
~~~

The script automatically removes empty alignments. There are 2 additional variants of the script: `multi-trimal-10minus.sh` and `multi-trimal-90plus.sh`. Depending on the sequence identity, they may be more useful. Building an initial phylogenetic tree using VeryFastTree should not take a lot of time time:

~~~
VeryFastTree -threads $(nproc) multi-trimal-out/HTT-result.fa.LCS.famsa.gt005.fa > multi-trimal-out/HTT-result.fa.LCS.famsa.gt005.fa.vft
~~~

As a convenience script downstream tree building, there are 2 scripts: `formatFigtree2.pl` and `f2f.sh`. We will use the latter to recolor the tree tips according to the database color scheme:

~~~
f2f.sh multi-trimal-out/HTT-result.fa.LCS.famsa.gt005.fa.vft
~~~

The output will be a Nexus file `multi-trimal-out/HTT-result.fa.LCS.famsa.gt005.fa.vft.fgcol`, which can be opened in FigTree, for example:

~~~
figtree multi-trimal-out/HTT-result.fa.LCS.famsa.gt005.fa.vft.fgcol
~~~

Another useful procedure is clustering sequences to remuve redundancy. A common piece of software to do this is cd-hit. A wrapper for cd-hit, `multi-cd-hit.cd` was written to simplify the choice of clustering parameters. Command example:

~~~
$LPMETADATA/examples/huntingtin_example && multi-cd-hit.sh HTT-result.fa
~~~

Ignoring the cd-hit output, this should be the result:

~~~
multi-cd-hit-out/HTT-result.fa.50  FASTA   Protein       521    586,832       62  1,126.4    3,936
multi-cd-hit-out/HTT-result.fa.60  FASTA   Protein       594    654,880       62  1,102.5    3,936
multi-cd-hit-out/HTT-result.fa.65  FASTA   Protein       630    686,416       62  1,089.5    3,936
multi-cd-hit-out/HTT-result.fa.70  FASTA   Protein       663    719,175       62  1,084.7    3,936
multi-cd-hit-out/HTT-result.fa.80  FASTA   Protein       751    796,634       62  1,060.8    3,936
multi-cd-hit-out/HTT-result.fa.90  FASTA   Protein       836    894,679       62  1,070.2    3,936
multi-cd-hit-out/HTT-result.fa.95  FASTA   Protein       893    955,271       62  1,069.7    3,936
multi-cd-hit-out/HTT-result.fa.99  FASTA   Protein       984  1,052,492       62  1,069.6    3,936
HTT-result.fa                      FASTA   Protein     1,145  1,347,867       62  1,177.2    3,936
~~~

One can then proceed to inspect the files and choose the parameters that are suitable.
