#!/bin/bash

# usage: first put the search phrase, then the file to extract the sequences from

RED='\033[0;31m'
GREEN='\033[0;32m'
BLUE='\033[0;34m'
NOCOLOR='\033[0m'

if [ -z "$LPMETADATA" ]; then echo -e "\nPlease export the LPMETADATA environment variable like so:\n\n\
     ${GREEN}export LPMETADATA=/path/to/LPMETADATA${NOCOLOR}\n"
exit 1

elif [ -z "$*" ]; then echo -e "\nUsage:\nThe first argument is the search phrase, the second argument is the FASTA file.\n\n\
Usage examples:\n\n\
     ${GREEN}seqkit_extract_LP_seqs_using_lpidlist.sh 31 fasta.fa${NOCOLOR}\n\n\
     This will generate a FASTA file '${RED}fasta.fa.31_Metazoa.fa${NOCOLOR}' and only with metazoan sequences.\n\n\
     ${GREEN}seqkit_extract_LP_seqs_using_lpidlist.sh LCS fasta.fa${NOCOLOR}\n\n\
     This will generate a FASTA file '${RED}fasta.fa.LCS.fa${NOCOLOR}' and only with LukProt Comparative Set sequences.\n\n\
You can also use the ID list name or its part to search, for example:\n\n\
     ${GREEN}seqkit_extract_LP_seqs_using_lpidlist.sh Metazoa${NOCOLOR}\n\
     or\n\
     ${GREEN}seqkit_extract_LP_seqs_using_lpidlist.sh Metazoa fasta.fa${NOCOLOR}\n\n\
     This will print a list of matching LukProt ID lists (24, 30 and 31)\n\n\n"
fi

if [ `find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid|wc -l` -gt 1 ]
then
	echo -e "Need to match just one ID list name, but the phrase \"$1\" matches $(find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid|wc -l)! Here is a list of matches for you:\n"
	find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid -type f -printf "%f\n"|sort
	elif [ `find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid|wc -l` -eq 1 ]
		then
		# find the name, return the reduced fasta
		echo "Extracting sequences from $(find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid -type f -printf "%f\n"|rev|cut -c6-|rev)." 
		seqkit grep -r -f $(find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid) -w 0\
		-o "$2".$(find $LPMETADATA/taxogroups_limiting/ -regex .*"$1".*.lpid -type f -printf "%f\n"|rev|cut -c6-|rev).fa $2
		seqkit stats -b "$2" "$2".*.fa
	else
	echo -e "\nNothing found for the search phrase \"$1\", check the expression."
	exit 0
fi

exit 0
